pub struct ExternalFunctions {
pub functions: Arc<Mutex<HashMap<String, FunctionProxy>>>,
/* private fields */
}Fields
functions: Arc<Mutex<HashMap<String, FunctionProxy>>>Implementations
Sourceimpl ExternalFunctions
impl ExternalFunctions
pub fn new(path_to_plugin: &PathBuf) -> ExternalFunctions
Sourcepub unsafe fn load<P: AsRef<OsStr>>(&mut self, library_path: P) -> Result<()>
pub unsafe fn load<P: AsRef<OsStr>>(&mut self, library_path: P) -> Result<()>
Load a plugin library and add all contained functions to the internal function table.
Safety
A plugin library must be implemented using the
[plugins_core::plugin_declaration!()] macro. Trying manually implement
a plugin without going through that macro will result in undefined
behaviour.
pub fn load_from_file(&mut self, plugin_path: &PathBuf) -> Result<()>
pub fn call( &self, function: &str, arguments: Value, ) -> Result<String, InvocationError>
pub fn has(&self, key: &str) -> bool